# ------------------------------------------------------------------------------
#  Copyright 2022 Upstream Data Inc                                            -
#                                                                              -
#  Licensed under the Apache License, Version 2.0 (the "License");             -
#  you may not use this file except in compliance with the License.            -
#  You may obtain a copy of the License at                                     -
#                                                                              -
#      http://www.apache.org/licenses/LICENSE-2.0                              -
#                                                                              -
#  Unless required by applicable law or agreed to in writing, software         -
#  distributed under the License is distributed on an "AS IS" BASIS,           -
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.    -
#  See the License for the specific language governing permissions and         -
#  limitations under the License.                                              -
# ------------------------------------------------------------------------------

from .S19 import (
    BOSMinerS19,
    BOSMinerS19a,
    BOSMinerS19aPro,
    BOSMinerS19j,
    BOSMinerS19jNoPIC,
    BOSMinerS19jPro,
    BOSMinerS19jProNoPIC,
    BOSMinerS19jProPlus,
    BOSMinerS19jProPlusNoPIC,
    BOSMinerS19kProNoPIC,
    BOSMinerS19Plus,
    BOSMinerS19Pro,
    BOSMinerS19ProPlusHydro,
    BOSMinerS19XP,
    BOSMinerS19XPHydro,
)
from .T19 import BOSMinerT19
